? my ($app, $window) = @_;
<li id="<?= $window->id ?>_tab" class="<?= $window->type ?>_tab <?= $window->{active} ? "active" : "" ?>">
  <div class="hit_area">
    <div class="tab_button" id="<?= $window->id ?>_tab_button"></div>
    <div style="float:left"><?= $window->title ?></div>
  </div>
</li>
